==> haskell-either-4.4.1.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1.1
id: either-4.4.1.1-DZvjiKJTHnBDhk4IjR75IV
key: either-4.4.1.1-DZvjiKJTHnBDhk4IjR75IV
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
abi: a103e15223a872c98e73765a7e7c0d49
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/either-4.4.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/either-4.4.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/either-4.4.1.1
hs-libraries: HSeither-4.4.1.1-DZvjiKJTHnBDhk4IjR75IV
depends:
    MonadRandom-0.4.2.3-8TfCm6PGvGYB7omozORhov base-4.9.0.0
    bifunctors-5.3-DOlu5HrqdrmIgON0ZSxlNq
    exceptions-0.8.2.1-BH4VJoBlnhODiEIhn43wEf
    free-4.12.4-SEuDyLHdpfFkS6mcOQdg7
    mmorph-1.0.6-3xsw6wg6Vs2JmwrJVsaYA0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    profunctors-5.2-BOnYvc9kLIi16aFzJiUAGc
    semigroupoids-5.0.1-JPPa1GAAznpIwjHipiGWj7
    semigroups-0.18.1-ESRONlmV7qgKe0wL9ZoBKD transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-4.4.1.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1.1
id: either-4.4.1.1-5BHivFikQaB8hzqa4ZGahe
key: either-4.4.1.1-5BHivFikQaB8hzqa4ZGahe
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
abi: a131ef476196e7a522ae65e6f7c3781b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/either-4.4.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/either-4.4.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/either-4.4.1.1
hs-libraries: HSeither-4.4.1.1-5BHivFikQaB8hzqa4ZGahe
depends:
    MonadRandom-0.4.2.3-8TfCm6PGvGYB7omozORhov base-4.9.0.0
    bifunctors-5.3-DOlu5HrqdrmIgON0ZSxlNq
    exceptions-0.8.2.1-BH4VJoBlnhODiEIhn43wEf
    free-4.12.4-9ks20BjLkfuIM98uYP5XGi
    mmorph-1.0.6-3xsw6wg6Vs2JmwrJVsaYA0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    profunctors-5.2-BOnYvc9kLIi16aFzJiUAGc
    semigroupoids-5.1-5jnCvjsOzwJ9gIFAA8m8gv
    semigroups-0.18.1-ESRONlmV7qgKe0wL9ZoBKD transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
